/**
 * @file synergy.cc
 * @brief SynergyǥХɥ饤ФؤΥ()
 *
 * @author Yashiro Takeshi <yashiromann@nifty.com> 
 * @date 2008-05-01
 *
 * Copyright (C) 2008, Yashiro Takeshi
 */

#include <basic.h>
#include <bstdio.h>
#include <btron/device.h>
#include <btron/libapp.h>
#include <itron/itron.h>
#include <driver/kbpd.h>
#include "int.h"
#include "synergy.h"

extern DEV_SPEC SCREEN;


#define DN_SYNERGY_PDMOVE    (-101) /* w */
#define DN_SYNERGY_PDRELMOVE (-102) /* w */
#define DN_SYNERGY_PDWHEEL   (-103) /* w */
#define DN_SYNERGY_PDINPUT   (-104) /* w */
#define DN_SYNERGY_PDLEAVE   (-105) /* w */
#define DN_SYNERGY_KEYINPUT  (-150) /* w */

typedef struct SynergyDriverPdMove_ {
  H    x;
  H    y;
  Bool enter;
} SynergyDriverPdMove;

typedef struct SynergyDriverPdRelMove_ {
  H    x;
  H    y;
} SynergyDriverPdRelMove;

typedef W SynergyDriverPdWheel;

typedef struct SynergyDriverPdInput_ {
  H    btn; // 1:left, 2:mid, 3:right
  H    rsv1;
  Bool on;
} SynergyDriverPdInput;

typedef W SynergyDriverPdLeave;

typedef struct SynergyDriverKeyInput_ {
  H    keytop;
  H    rsv1;
  Bool on;
} SynergyDriverKeyInput;


void synergy_set_pdabs(SynergyTaskInfo* info, PNT pos, bool enter)
{
  SynergyDriverPdMove ev;
  W asize, error;

  ev.x     = pos.x * PDIN_XMAX / SCREEN.hpixels;
  ev.y     = pos.y * PDIN_YMAX / SCREEN.vpixels;
  ev.enter = (enter ? True : False);

  wri_dev(info->driver, DN_SYNERGY_PDMOVE, (B*)&ev, 
          sizeof(SynergyDriverPdMove), &asize, &error);
}


void synergy_set_pdrel(SynergyTaskInfo* info, PNT pos)
{
  SynergyDriverPdRelMove ev;
  W asize, error;

  ev.x     = pos.x * PDIN_XMAX / SCREEN.hpixels;
  ev.y     = pos.y * PDIN_YMAX / SCREEN.vpixels;

  wri_dev(info->driver, DN_SYNERGY_PDRELMOVE, (B*)&ev, 
          sizeof(SynergyDriverPdRelMove), &asize, &error);
}


void synergy_set_wheel(SynergyTaskInfo* info, W wheel)
{
  W asize, error;

  wri_dev(info->driver, DN_SYNERGY_PDWHEEL, (B*)&wheel, 
          sizeof(W), &asize, &error);
}


void synergy_set_pdinput(SynergyTaskInfo* info, int btn, bool press)
{
  SynergyDriverPdInput ev;
  W asize, error;

  ev.btn  = btn;
  ev.rsv1 = 0;
  ev.on   = (press ? True : False);

  wri_dev(info->driver, DN_SYNERGY_PDINPUT, (B*)&ev,
          sizeof(SynergyDriverPdInput), &asize, &error);
}


void synergy_set_pdleave(SynergyTaskInfo* info)
{
  SynergyDriverPdLeave ev = 0;
  W asize, error;
  W err;

  wri_dev(info->driver, DN_SYNERGY_PDLEAVE, (B*)&ev,
          sizeof(SynergyDriverPdLeave), &asize, &error);
}


void synergy_set_keyinput(SynergyTaskInfo* info, int key, bool press)
{
  SynergyDriverKeyInput ev;
  W asize, error;

  ev.keytop = key;
  ev.rsv1   = 0;
  ev.on     = (press ? True : False);

  wri_dev(info->driver, DN_SYNERGY_KEYINPUT, (B*)&ev,
          sizeof(SynergyDriverKeyInput), &asize, &error);
}

