/**
 * @file keysym.cc
 * @brief ()
 *
 * @author Yashiro Takeshi <yashiromann@nifty.com> 
 * @date 2008-05-01
 *
 * Copyright (C) 2008, Yashiro Takeshi
 */

#include <basic.h>
#include <tcode.h>
#include <keycode.h>
#include <bstdio.h>
#include <btron/event.h>
#include <device/kbpd.h>
#include "int.h"
#include "keysym.h"


int keyid_to_physical(UINT16 keyid)
{
  switch (keyid) {
  case kKeyBackSpace:
    return 14;
  case kKeyTab:
    return 15;
  case kKeyLinefeed:
    return 28;
  case kKeyClear:
    return 0; // ???
  case kKeyReturn:
    return 28;
  case kKeyPause:
    return 130;
  case kKeyScrollLock:
    return 70;
  case kKeySysReq:
    return 0; // ???
  case kKeyEscape:
    return 1;
  case kKeyHenkan:
    return 121;
  case kKeyMuhenkan:
    return 123;
  case kKeyZenkaku:
    return 41;
  case kKeyDelete:
    return 132;
  case kKeyHome:
    return 133;
  case kKeyLeft:
    return 139;
  case kKeyUp:
    return 137;
  case kKeyRight:
    return 140;
  case kKeyDown:
    return 138;
  case kKeyPageUp:
    return 135;
  case kKeyPageDown:
    return 136;
  case kKeyEnd:
    return 134;
  case kKeyBegin:
    return 133;
  case kKeySelect:
    return 0; // ???
  case kKeyPrint:
    return 84;
  case kKeyExecute:
    return 0; // ???
  case kKeyInsert:
    return 131;
  case kKeyUndo:
    return 0; // ???
  case kKeyRedo:
    return 0; // ???
  case kKeyMenu:
    return 0; // ???
  case kKeyFind:
    return 0; // ???
  case kKeyCancel:
    return 1;
  case kKeyHelp:
    return 0; // ???
  case kKeyBreak:
    return 130;
  case kKeyAltGr:
    return 0; // ???
  case kKeyNumLock:
    return 0; // ???
  case kKeyKP_Space:
    return 57;
  case kKeyKP_Tab:
    return 15;
  case kKeyKP_Enter:
    return 142;
  case kKeyKP_F1:
    return 59;
  case kKeyKP_F2:
    return 60;
  case kKeyKP_F3:
    return 61;
  case kKeyKP_F4:
    return 62;
  case kKeyKP_Home:
    return 143;
  case kKeyKP_Left:
    return 147;
  case kKeyKP_Up:
    return 144;
  case kKeyKP_Right:
    return 149;
  case kKeyKP_Down:
    return 152;
  case kKeyKP_PageUp:
    return 145;
  case kKeyKP_PageDown:
    return 155;
  case kKeyKP_End:
    return 151;
  case kKeyKP_Begin:
    return 143;
  case kKeyKP_Insert:
    return 154;
  case kKeyKP_Delete:
    return 155;
  case kKeyKP_Equal:
    return 0; // ???
  case kKeyKP_Multiply:
    return 55;
  case kKeyKP_Add:
    return 78;
  case kKeyKP_Separator:
    return 0; // ???
  case kKeyKP_Subtract:
    return 74;
  case kKeyKP_Decimal:
    return 83;
  case kKeyKP_Divide:
    return 141;
  case kKeyKP_0:
    return 82;
  case kKeyKP_1:
    return 79;
  case kKeyKP_2:
    return 80;
  case kKeyKP_3:
    return 81;
  case kKeyKP_4:
    return 75;
  case kKeyKP_5:
    return 76;
  case kKeyKP_6:
    return 77;
  case kKeyKP_7:
    return 71;
  case kKeyKP_8:
    return 72;
  case kKeyKP_9:
    return 73;
  case kKeyF1:
    return 59;
  case kKeyF2:
    return 60;
  case kKeyF3:
    return 61;
  case kKeyF4:
    return 62;
  case kKeyF5:
    return 63;
  case kKeyF6:
    return 64;
  case kKeyF7:
    return 65;
  case kKeyF8:
    return 66;
  case kKeyF9:
    return 67;
  case kKeyF10:
    return 68;
  case kKeyF11:
    return 87;
  case kKeyF12:
    return 88;
  case kKeyShift_L:
    return 42;
  case kKeyShift_R:
    return 54;
  case kKeyControl_L:
    return 29;
  case kKeyControl_R:
    return 129;
  case kKeyCapsLock:
  case kKeyEisu_toggle:
    return 58;
  case kKeyShiftLock:
    return 0; // ???
  case kKeyMeta_L:
  case kKeyAlt_L:
    return 56;
  case kKeyMeta_R:
  case kKeyAlt_R:
    return 128;
  case kKeyLeftTab:
    return 15;
  case kKeyHiragana_Katakana:
    return 112;
  case '1':
  case '!':
    return 2;
  case '2':
  case '\"':
    return 3;
  case '3':
  case '#':
    return 4;
  case '4':
  case '$':
    return 5;
  case '5':
  case '%':
    return 6;
  case '6':
  case '&':
    return 7;
  case '7':
  case '\'':
    return 8;
  case '8':
  case '(':
    return 9;
  case '9':
  case ')':
    return 10;
  case '0':
    return 11;
  case '-':
  case '=':
    return 12;
  case '^':
  case '~':
    return 13;
  case 'q':
  case 'Q':
    return 16;
  case 'w':
  case 'W':
    return 17;
  case 'e':
  case 'E':
    return 18;
  case 'r':
  case 'R':
    return 19;
  case 't':
  case 'T':
    return 20;
  case 'y':
  case 'Y':
    return 21;
  case 'u':
  case 'U':
    return 22;
  case 'i':
  case 'I':
    return 23;
  case 'o':
  case 'O':
    return 24;
  case 'p':
  case 'P':
    return 25;
  case '@':
  case '`':
    return 26;
  case '[':
  case '{':
    return 27;
  case 'a':
  case 'A':
    return 30;
  case 's':
  case 'S':
    return 31;
  case 'd':
  case 'D':
    return 32;
  case 'f':
  case 'F':
    return 33;
  case 'g':
  case 'G':
    return 34;
  case 'h':
  case 'H':
    return 35;
  case 'j':
  case 'J':
    return 36;
  case 'k':
  case 'K':
    return 37;
  case 'l':
  case 'L':
    return 38;
  case ';':
  case '+':
    return 39;
  case ':':
  case '*':
    return 40;
  case ']':
  case '}':
    return 43;
  case 'z':
  case 'Z':
    return 44;
  case 'x':
  case 'X':
    return 45;
  case 'c':
  case 'C':
    return 46;
  case 'v':
  case 'V':
    return 47;
  case 'b':
  case 'B':
    return 48;
  case 'n':
  case 'N':
    return 49;
  case 'm':
  case 'M':
    return 50;
  case ',':
  case '<':
    return 51;
  case '.':
  case '>':
    return 52;
  case '/':
  case '?':
    return 53;
  case '_':
//  case '\\': // ʣƤ
    return 115;
  case '\\':
  case '|':
    return 125;
  case ' ':
    return 57;
  default:
    return 0;
  }
}

