/**
 * @file keysym.h
 * @brief 
 *
 * synergy -- mouse and keyboard sharing utility
 * Copyright (C) 2002 Chris Schoeneman
 * 
 * This package is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * found in the file COPYING that should have accompanied this file.
 * 
 * This package is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

// Υեϡꥸʥ synergy 1.3.1  KeyTypes.h 
// ˡѹäΤǤ

#ifndef DEFINE_H_KEYSYM
#define DEFINE_H_KEYSYM

#include <basic.h>
#include "int.h"

#define kKeyNone 0x0000

// TTY functions
#define kKeyBackSpace 0xEF08 /* back space, back char */
#define kKeyTab  0xEF09
#define kKeyLinefeed 0xEF0A /* Linefeed, LF */
#define kKeyClear 0xEF0B
#define kKeyReturn 0xEF0D /* Return, enter */
#define kKeyPause 0xEF13 /* Pause, hold */
#define kKeyScrollLock 0xEF14
#define kKeySysReq 0xEF15
#define kKeyEscape 0xEF1B
#define kKeyHenkan 0xEF23 /* Start/Stop Conversion */
#define kKeyZenkaku 0xEF2A /* Zenkaku/Hankaku */
#define kKeyDelete 0xEFFF /* Delete, rubout */

// cursor control
#define kKeyHome 0xEF50
#define kKeyLeft 0xEF51 /* Move left, left arrow */
#define kKeyUp  0xEF52 /* Move up, up arrow */
#define kKeyRight 0xEF53 /* Move right, right arrow */
#define kKeyDown 0xEF54 /* Move down, down arrow */
#define kKeyPageUp 0xEF55
#define kKeyPageDown 0xEF56
#define kKeyEnd  0xEF57 /* EOL */
#define kKeyBegin 0xEF58 /* BOL */

// misc functions
#define kKeySelect 0xEF60 /* Select, mark */
#define kKeyPrint 0xEF61
#define kKeyExecute 0xEF62 /* Execute, run, do */
#define kKeyInsert 0xEF63 /* Insert, insert here */
#define kKeyUndo 0xEF65 /* Undo, oops */
#define kKeyRedo 0xEF66 /* redo, again */
#define kKeyMenu 0xEF67
#define kKeyFind 0xEF68 /* Find, search */
#define kKeyCancel 0xEF69 /* Cancel, stop, abort, exit */
#define kKeyHelp 0xEF6A /* Help */
#define kKeyBreak 0xEF6B
#define kKeyAltGr   0xEF7E /* Character set switch */
#define kKeyNumLock 0xEF7F

// keypad
#define kKeyKP_Space 0xEF80 /* space */
#define kKeyKP_Tab 0xEF89
#define kKeyKP_Enter 0xEF8D /* enter */
#define kKeyKP_F1 0xEF91 /* PF1, KP_A, ... */
#define kKeyKP_F2 0xEF92
#define kKeyKP_F3 0xEF93
#define kKeyKP_F4 0xEF94
#define kKeyKP_Home 0xEF95
#define kKeyKP_Left 0xEF96
#define kKeyKP_Up 0xEF97
#define kKeyKP_Right 0xEF98
#define kKeyKP_Down 0xEF99
#define kKeyKP_PageUp 0xEF9A
#define kKeyKP_PageDown 0xEF9B
#define kKeyKP_End 0xEF9C
#define kKeyKP_Begin 0xEF9D
#define kKeyKP_Insert 0xEF9E
#define kKeyKP_Delete 0xEF9F
#define kKeyKP_Equal 0xEFBD /* equals */
#define kKeyKP_Multiply 0xEFAA
#define kKeyKP_Add 0xEFAB
#define kKeyKP_Separator 0xEFAC
#define kKeyKP_Subtract 0xEFAD
#define kKeyKP_Decimal 0xEFAE
#define kKeyKP_Divide 0xEFAF
#define kKeyKP_0 0xEFB0 
#define kKeyKP_1 0xEFB1
#define kKeyKP_2 0xEFB2
#define kKeyKP_3 0xEFB3
#define kKeyKP_4 0xEFB4
#define kKeyKP_5 0xEFB5
#define kKeyKP_6 0xEFB6
#define kKeyKP_7 0xEFB7
#define kKeyKP_8 0xEFB8
#define kKeyKP_9 0xEFB9

// function keys
#define kKeyF1  0xEFBE
#define kKeyF2  0xEFBF
#define kKeyF3  0xEFC0
#define kKeyF4  0xEFC1
#define kKeyF5  0xEFC2
#define kKeyF6  0xEFC3
#define kKeyF7  0xEFC4
#define kKeyF8  0xEFC5
#define kKeyF9  0xEFC6
#define kKeyF10  0xEFC7
#define kKeyF11  0xEFC8
#define kKeyF12  0xEFC9
#define kKeyF13  0xEFCA
#define kKeyF14  0xEFCB
#define kKeyF15  0xEFCC
#define kKeyF16  0xEFCD
#define kKeyF17  0xEFCE
#define kKeyF18  0xEFCF
#define kKeyF19  0xEFD0
#define kKeyF20  0xEFD1
#define kKeyF21  0xEFD2
#define kKeyF22  0xEFD3
#define kKeyF23  0xEFD4
#define kKeyF24  0xEFD5
#define kKeyF25  0xEFD6
#define kKeyF26  0xEFD7
#define kKeyF27  0xEFD8
#define kKeyF28  0xEFD9
#define kKeyF29  0xEFDA
#define kKeyF30  0xEFDB
#define kKeyF31  0xEFDC
#define kKeyF32  0xEFDD
#define kKeyF33  0xEFDE
#define kKeyF34  0xEFDF
#define kKeyF35  0xEFE0

// modifiers
#define kKeyShift_L 0xEFE1 /* Left shift */
#define kKeyShift_R 0xEFE2 /* Right shift */
#define kKeyControl_L 0xEFE3 /* Left control */
#define kKeyControl_R 0xEFE4 /* Right control */
#define kKeyCapsLock 0xEFE5 /* Caps lock */
#define kKeyShiftLock 0xEFE6 /* Shift lock */
#define kKeyMeta_L 0xEFE7 /* Left meta */
#define kKeyMeta_R 0xEFE8 /* Right meta */
#define kKeyAlt_L 0xEFE9 /* Left alt */
#define kKeyAlt_R 0xEFEA /* Right alt */
#define kKeySuper_L 0xEFEB /* Left super */
#define kKeySuper_R 0xEFEC /* Right super */
#define kKeyHyper_L 0xEFED /* Left hyper */
#define kKeyHyper_R 0xEFEE /* Right hyper */

// multi-key character composition
#define kKeyCompose  0xEF20
#define kKeyDeadGrave 0x0300
#define kKeyDeadAcute 0x0301
#define kKeyDeadCircumflex 0x0302
#define kKeyDeadTilde 0x0303
#define kKeyDeadMacron 0x0304
#define kKeyDeadBreve 0x0306
#define kKeyDeadAbovedot 0x0307
#define kKeyDeadDiaeresis 0x0308
#define kKeyDeadAbovering 0x030a
#define kKeyDeadDoubleacute 0x030b
#define kKeyDeadCaron 0x030c
#define kKeyDeadCedilla 0x0327
#define kKeyDeadOgonek 0x0328

// more function and modifier keys
#define kKeyLeftTab  0xEE20

// update modifiers
#define kKeySetModifiers 0xEE06
#define kKeyClearModifiers 0xEE07

// group change
#define kKeyNextGroup 0xEE08
#define kKeyPrevGroup 0xEE0A

// extended keys
#define kKeyEject  0xE001
#define kKeySleep  0xE05F
#define kKeyWWWBack  0xE0A6
#define kKeyWWWForward 0xE0A7
#define kKeyWWWRefresh 0xE0A8
#define kKeyWWWStop  0xE0A9
#define kKeyWWWSearch 0xE0AA
#define kKeyWWWFavorites 0xE0AB
#define kKeyWWWHome  0xE0AC
#define kKeyAudioMute 0xE0AD
#define kKeyAudioDown 0xE0AE
#define kKeyAudioUp  0xE0AF
#define kKeyAudioNext 0xE0B0
#define kKeyAudioPrev 0xE0B1
#define kKeyAudioStop 0xE0B2
#define kKeyAudioPlay 0xE0B3
#define kKeyAppMail  0xE0B4
#define kKeyAppMedia 0xE0B5
#define kKeyAppUser1 0xE0B6
#define kKeyAppUser2 0xE0B7

// additional
#define kKeyHiragana_Katakana 0xef27
#define kKeyMuhenkan 0xef22
#define kKeyEisu_toggle 0xef30

#endif // DEFINE_H_KEYSYM
